
##### functions to generate chemistry plots ----


##### plot data, quick look separated by pre-col, 1st colonized, 1st uncolonized, 3rd colonized, 3rd uncolonized

plot_ratio_distribution <- function(ratio_to_plot) {
    ymin <- min(meta_chem[ ,deparse(substitute(ratio_to_plot))])
    ymax <- max(meta_chem[ ,deparse(substitute(ratio_to_plot))])
    ggpubr::ggarrange(
        ggplot(data = subset(meta_chem, sampling_time == "t0"),
               aes(x = site, y = {{ratio_to_plot}}, col = tree)) +
            geom_point() + ylim(c(ymin, ymax)) +
            ggtitle("pre-col"),

        ggplot(data = subset(meta_chem, sampling_time == "t1" & bb_colonization == "colonized"),
               aes(x = site, y = {{ratio_to_plot}}, col = tree)) +
            geom_boxplot(fill = NA) + ylim(c(ymin, ymax)) +
            ggtitle("1st instar, colonized"),

        ggplot(data = subset(meta_chem, sampling_time == "t1" & bb_colonization == "uncolonized"),
               aes(x = site, y = {{ratio_to_plot}}, col = tree)) +
            geom_boxplot(fill = NA) + ylim(c(ymin, ymax)) +
            ggtitle("1st instar, uncolonized"),

        ggplot(data = subset(meta_chem, sampling_time == "t2" & bb_colonization == "colonized"),
               aes(x = site, y = {{ratio_to_plot}}, col = tree)) +
            geom_boxplot(fill = NA) + ylim(c(ymin, ymax)) +
            ggtitle("3rd instar, colonized"),

        ggplot(data = subset(meta_chem, sampling_time == "t2" & bb_colonization == "uncolonized"),
               aes(x = site, y = {{ratio_to_plot}}, col = tree)) +
            geom_boxplot(fill = NA) + ylim(c(ymin, ymax)) +
            ggtitle("3rd instar, uncolonized"),
        legend = "none")

}



##### generate supplementary plot with precol values only

precol_plot_comb <- function(meta_df) {
    met <- meta_df
    precol_plot_base <- function(nutrient) {
        nutr <- deparse(substitute(nutrient))
        y_lab <- case_when(nutr == "cn_ratio" ~ "C:N",
                           nutr == "cp_ratio" ~ "C:P",
                           nutr == "np_ratio" ~ "N:P")
        p <- subset(met, sampling_time == "t0") %>%
            ggplot(aes(x = fire_hist, y = {{nutrient}}, col = site)) +
#            geom_boxplot(col = 'grey77', fill = NA, show.legend = FALSE, width = 0.5) +
            geom_point() +
            scale_color_manual("site: ",
                               values = c(`KB`  = "#330543",
                                          `HSB` = "#28557C",
                                          `SK`  = "#39AB63",
                                          `OJ`  = "#FCE200"),
                               labels = c(`KB`  = "Knutby",
                                          `HSB` = "Hälleskogsbrännan",
                                          `SK`  = "Skyttorp",
                                          `OJ`  = "Ecopark Öjesjön")) +
            scale_y_continuous(labels = scales::comma) +
            scale_x_discrete(labels = c(`unburnt` = "Unburnt\nsites",
                                        `burnt` = "Burnt\nsites")) +
            labs(y = y_lab) +
            theme_linedraw() +
            theme_legend() +
            theme(axis.title.x = element_blank(),
                  axis.text.x = element_text(size = 8, color = "black"),
                  panel.grid = element_blank(),
                  legend.box.background = element_blank())
        return(p)
}

    p <- ggpubr::ggarrange(precol_plot_base(cn_ratio),
                   precol_plot_base(cp_ratio),
                   precol_plot_base(np_ratio),
                   ncol = 3, align = "hv", legend = "bottom", common.legend = TRUE)
    return(p)
}



## generate main plot
## tree colors = either 'color_by_tree' or 'color_by_tree_3color'
##                     re-labeller (see above)
## met_long = either be with measured ratio values in long format ('meta_chem_long')
##                     or predicted ratio values in long format ('meta_chem_pred_long')

chem_fig_plotter <- function(met_long, dodge_w, tree_colors) {
    met_long %>%
    ggplot(
        aes(x = sampling_time,
            y = nutrient_ratio_value,
            col = tree,
            group = tree,
            pch = bb_colonization
        )
    ) +
     geom_point(
        position = position_dodge(width = dodge_w)
    ) +
    scale_shape_manual(
        "Colonization status: ",
        values = c(
            `pre-colonization` = 23,
            `uncolonized`      = 6,
            `colonized`        = 20
        ),
        labels = c(
            `pre-colonization` = "(pre-colonization)",
            `uncolonized`      = "Uncolonized phloem",
            `colonized`        = "Colonized phloem"
        ),
        guide = guide_legend(reverse = TRUE, order = 1)
    ) +
    scale_color_manual(
        "Tree sampled: ", values = {{tree_colors}},
        guide = guide_legend(nrow = 2,
                             byrow = TRUE,
                             order = 2,
                             title.vjust = 0.5,
                             label.hjust = 0.5),
        breaks = c("K2", "K3", "K5", "H1", "H2", "H3",
                   "S2", "S3", "S5", "O1", "O2", "O4")
    ) +
    scale_y_continuous(labels = scales::comma) +
    scale_x_discrete(
        "Bark beetle larvel stage at time of phloem sampling",
        labels = c(
            `t0` = "(pre)",
            `t1` = "1st\ninstar",
            `t2` = "3rd\ninstar",
            ` ` = " "
        ),
        expand = c(0.1, 0.1),
        drop = FALSE
    ) +
        theme_stripped()


}

## add facets, either by site (4 columns) or by fire history (2 columns)
chem_fig_plotter_add_facet <- function(plot_without_facets, facet_by) {

    if (facet_by == "fire history") {
        facet_breaks <- substitute(fire_hist)
    } else if (facet_by == "site") {
        facet_breaks <- substitute(site)
    } else {
        stop("\'facet_by\' must be either \"fire history\" or \"site\"")
    }

        plot_without_facets +
        facet_grid(
            cols = vars(eval(facet_breaks)),
            rows = vars(nutrient_ratio_label),
            scales = "free",
            space = "fixed",
            switch = "y",
            labeller = as_labeller(chem_facet_labeller)
        )
}

chem_fig_plotter_add_facet_fixed <- function(plot_without_facets, facet_by) {

    if (facet_by == "fire history") {
        facet_breaks <- substitute(fire_hist)
    } else if (facet_by == "site") {
        facet_breaks <- substitute(site)
    } else {
        stop("\'facet_by\' must be either \"fire history\" or \"site\"")
    }

        plot_without_facets +
        facet_grid(
            cols = vars(eval(facet_breaks)),
            rows = vars(nutrient_ratio_label),
            scales = "fixed",
            space = "fixed",
            switch = "y",
            labeller = as_labeller(chem_facet_labeller)
        )
}


## add lines connecting means of sample types
chem_fig_plotter_addlines <- function(fig_without_lines, met_long, dodge_w) {
    fig_without_lines +
        stat_summary(
            data = subset(met_long, bb_colonization == "colonized" & sampling_time != "t0"),
            fun = mean,
            geom = "line",
            position = position_dodge(width = dodge_w),
            lty = 1
        ) +
        stat_summary(
            data = subset(met_long, bb_colonization == "uncolonized" & sampling_time != "t0"),
            fun = mean,
            geom = "line",
            position = position_dodge(width = dodge_w),
            lty = 2
        ) +
        stat_summary(
            data = subset(met_long, bb_colonization != "colonized" & sampling_time != "t2"),
            fun = mean,
            geom = "line",
            position = position_dodge(width = dodge_w),
            lty = 1,
            size = 0.3,
            alpha = 0.3
        ) +
        stat_summary(
            data = subset(met_long, bb_colonization != "uncolonized" & sampling_time != "t2"),
            fun = mean,
            geom = "line",
            position = position_dodge(width = dodge_w),
            lty = 1,
            size = 0.3,
            alpha = 0.3
        )
}


