
# this script will format the metadata for analysis and visualization
# last revised: 14 July 2021


# format variables as factors ad order levels
# create variables 'substrate_collapsed_4' and 'hm_grp'
meta <- meta_in %>%
    mutate(
        site = factor(
            site,
            levels = c("KB", "SK", "HSB", "OJ")
        ),
        bb_colonization = factor(
            bb_colonization,
            levels = c("pre-colonization", "colonized", "uncolonized")
        ),
        substrate = factor(
            substrate,
            levels = c("female, body", "female, gut", "male, body", "male, gut",
                       "pre-colonization", "1st instar, uncolonized", "1st instar, colonized",
                       "3rd instar, uncolonized", "3rd instar, colonized")
        ),
        fire_hist = factor(
            fire_hist,
            levels = c("unburnt", "burnt")
        ),
        tree = factor(
            tree,
            levels = c("K2", "K3", "K5", "S2", "S3", "S5",
                       "H1", "H2", "H3", "O1", "O2", "O4")
        ),
        sampling_time = factor(
            sampling_time,
            levels = c("t0", "t1", "t2")
        ),
        substrate_collapsed_4 = case_when(
            grepl("BB_", substrate_abbr) ~ "beetle",
            grepl("_UNCOL_", substrate_abbr) | grepl("PRECOL", substrate_abbr) ~ "phloem, no larvae",
            grepl("_COL_1ST", substrate_abbr) ~ "phloem, 1st instar",
            grepl("_COL_3RD", substrate_abbr) ~ "phloem, 3rd instar"
        )) %>%
    unite(
        "hm_grp", fire_hist, substrate_collapsed_4, sep = "_", remove = FALSE
    ) %>%
    select(
        tag, seq_plate, sample_id, site, fire_hist, tree, sampling_time, substrate_abbr,
        substrate, bb_colonization, substrate_collapsed_4, hm_grp,
        cn_ratio, cp_ratio, np_ratio
    ) %>%
    droplevels()

# subset meta to include only samples with sequence data
meta_seq <- meta %>%
    filter(!is.na(tag)) %>%
    select(-tag, -cn_ratio, -cp_ratio, -np_ratio)

# subset meta to include only samples with chemistry data
meta_chem <- meta %>%
    filter(!is.na(cn_ratio)) %>%
    select(-tag, -hm_grp, -substrate_collapsed_4)


# make long format for plotting nutrients separately (as facets)
# pre-colonization ratios for each tree treated as a variable
# each sample as a row, and pre-colonization nutrient ratios as variable "precol_nutrient_ratio"

# met_chem, long format
meta_chem_long <- meta_chem %>%
    filter(sampling_time == "t0") %>%
    select(tree, cn_ratio, cp_ratio, np_ratio) %>%
    rename(precol_cn = "cn_ratio",
           precol_cp = "cp_ratio",
           precol_np = "np_ratio") %>%
    left_join(meta_chem, ., by = "tree") %>%
    pivot_longer(cols = c("cn_ratio", "cp_ratio", "np_ratio"),
                 names_to = "nutrient_ratio_label", values_to = "nutrient_ratio_value") %>%
    droplevels()

# meta_chem, t1 and t2 samples only
meta_chem_t1t2 <- meta_chem %>%
    filter(sampling_time == "t0") %>%
    select(tree, cn_ratio, cp_ratio, np_ratio) %>%
    rename(precol_cn = "cn_ratio",
           precol_cp = "cp_ratio",
           precol_np = "np_ratio") %>%
    left_join(meta_chem, ., by = "tree") %>%
    filter(sampling_time != "t0") %>%
    droplevels()

# meta_chem_t1t2, unburnt samples only
meta_chem_t1t2_unburnt <- subset(meta_chem_t1t2, fire_hist == "unburnt") %>%
    droplevels()

# meta_chem_t1t2, burnt samples only
meta_chem_t1t2_burnt <- subset(meta_chem_t1t2, fire_hist == "burnt") %>%
    droplevels()
