
# function to get core community (requires vegan package)
# usage :
# get_core_community(meta = meta10,  ## metadata file
#   group_var = "hm_grp",  ## grouping variable
#   otu_mat = otutab_min10,  ## otu table
#   freq_lim = 0.3,  ## minimum average frequency
#   avg_ra_lim = 0.01) ## minimum average relative abundance

get_core_community <-
    function(meta,
             group_var,
             otu_mat,
             freq_lim,
             avg_ra_lim)
    {
        groups <- levels(as.factor(meta[, group_var]))
        otumat_ra <- vegan::decostand(otu_mat, method = "total")
        otumat_pa <- vegan::decostand(otu_mat, method = "pa")
        core_otus_all <- NULL
        for (group in groups) {
            samples_in_group <-
                row.names(subset(meta, meta[, group_var] == group))
            n_samples_in_group <- length(samples_in_group)
            group_ra <-
                subset(otumat_ra, row.names(otumat_ra) %in% samples_in_group)
            group_pa <-
                subset(otumat_pa, row.names(otumat_pa) %in% samples_in_group)
            otu_freq_in_group <- colSums(group_pa) / n_samples_in_group
            most_freq_otus <- which(otu_freq_in_group >= freq_lim)
            otu_avg_abund_in_group <- colSums(group_ra) / n_samples_in_group
            most_abund_otus <- which(otu_avg_abund_in_group >= avg_ra_lim)
            core_otus_group <-
                intersect(names(most_freq_otus), names(most_abund_otus))
            core_otus_all <- c(core_otus_all, core_otus_group)
        }
        return(unique(core_otus_all))
    }
