
# a script to plot a heatmap of core OTUs



# row/column orders for heatmap
group_order <-
  c("unburnt_beetle",
    "unburnt_phloem, 3rd instar",
    "unburnt_phloem, 1st instar",
    "unburnt_phloem, no larvae",
    "burnt_phloem, no larvae",
    "burnt_phloem, 1st instar",
    "burnt_phloem, 3rd instar",
    "burnt_beetle"
    )

tax_order <-
  c("scata3997_2",
    "scata3997_15",
    "scata3997_6",
    "scata3997_5",
    "scata3997_0",
    "scata3997_19",
    "scata3997_17",
    "scata3997_8",
    "scata3997_13",
    "scata3997_22",
    "scata3997_3",
    "scata3997_7",
    "scata3997_28",
    "scata3997_11",
    "scata3997_36"
    )

label_by_hm_grp <-
  c(`unburnt_beetle` = "beetle",
    `unburnt_phloem, 3rd instar` = "phloem, 3rd instar",
    `unburnt_phloem, 1st instar` = "phloem, 1st instar",
    `unburnt_phloem, no larvae` = "phloem, no larvae",
    `burnt_phloem, no larvae` = "phloem, no larvae",
    `burnt_phloem, 1st instar` = "phloem, 1st instar",
    `burnt_phloem, 3rd instar` = "phloem, 3rd instar",
    `burnt_beetle` = "beetle"
    )

# taxonomy labels
label_by_tax_order <-
  c(`scata3997_2` = "OTU_2 Helotiales sp.",
    `scata3997_15` = "OTU_15 Herpotrichiellaceae sp.",
    `scata3997_6` = "OTU_6 Saccharomycetales sp. 1",
    `scata3997_5` = "OTU_5 Yamadazyma mexicana",
    `scata3997_0` = "OTU_0 Ogataea saltuana",
    `scata3997_19` = "OTU_19 Saccharomycetales sp. 2",
    `scata3997_17` = "OTU_17 Penicillium sp. 1",
    `scata3997_8` = "OTU_8 Mycosphaerella tassiana",
    `scata3997_13` = "OTU_13 Candida sequanensis",
    `scata3997_22` = "OTU_22 Ascomycota sp.",
    `scata3997_3` = "OTU_3 Nakazawaea holstii",
    `scata3997_7` = "OTU_7 Sydowia polyspora",
    `scata3997_28` = "OTU_28 Penicillium sp. 2",
    `scata3997_11` = "OTU_11 Chalara sp.",
    `scata3997_36` = "OTU_36 Filobasidium wieringae"
    )






# subset metadata table
meta_seq_min10 <- meta_seq[row.names(meta_seq) %in% row.names(otutab_min10), ]

# identify core community
core_otus_hm_grp <- get_core_community(
    meta = meta_seq_min10,
    group_var = "hm_grp",
    otu_mat = otutab_min10,
    freq_lim = 0.3,  ## minimum presence in 30% of samples in group
    avg_ra_lim = 0.01  ## minimum average relative abundance of 1% in group
)

# subset otutable (min 10 reads) to include only columns for the identified core otus
# (remove non-core otus)
otutab_core_otus_only <- otutab_min10[, c(core_otus_hm_grp)]
otutab_core_otus_only_ra <- otutab_min10_ra[, c(core_otus_hm_grp)]

#merge this data with the metadata table
heatmap_data <- merge(meta_seq_min10, otutab_core_otus_only_ra, by = 0)



# identify how many reads this accounts for
# percent of otutab_min10 accounted for by core OTUs
percent_reads_core_otus <- sum(rowSums(otutab_core_otus_only)) / (sum(rowSums(otutab_min10)))



# format data for plotting heatmap
# values are scaled but not centered (for coloring cells of heatmap)

# calculate mean relative abundance of each otu in each sample group (hm_grp)
core_otu_mean_ra_per_hm_grp <-
    # table with only the hm_group and the core otus as columns
    heatmap_data[, c("hm_grp", core_otus_hm_grp)] %>%
    group_by(hm_grp) %>%
    summarise(across(where(is.numeric), mean)) %>%
    as.data.frame() %>%
    ungroup()

# move hm_grp (8 sample groups, see group order above for list) to row names
row.names(core_otu_mean_ra_per_hm_grp) <- core_otu_mean_ra_per_hm_grp$hm_grp
core_otu_mean_ra_per_hm_grp$hm_grp <- NULL

# multiple by 100 to get percentage, transpose the data so that otus are on rows
heatmap_df <- (core_otu_mean_ra_per_hm_grp * 100) %>% t() %>% as.data.frame()

# move the rownames (scata3997_#) to a column called 'taxon'
heatmap_df$taxon <- row.names(heatmap_df)

# reorder table so that the rows or in the order for ploting (see tax_order above)
heatmap_df$taxon <- factor(heatmap_df$taxon, levels = tax_order)

# transpose the table back so that otus are on columns in order to scale (but not center) data for each otu
# then transpose back so that otus are on rows again
heatmap_df_scaled <- t(heatmap_df[, c(1:8)]) %>%
    scale(., center = FALSE) %>%
    t() %>%
    as.data.frame()

# move row.names to variable called taxon, and reorder to ax_order above
heatmap_df_scaled$taxon <- row.names(heatmap_df_scaled)
heatmap_df_scaled$taxon <- factor(heatmap_df_scaled$taxon, levels = tax_order)

# get both tables in long format

#dataframe with three columns, 'taxon', hm_grp' and either 'mean_relab' or 'scaled_mean_relab'
heatmap_df_long <-
    pivot_longer(
        heatmap_df,
        names_to = "hm_8grp",
        values_to = "mean_relab",
        cols = -taxon
    )

heatmap_df_long$hm_8grp <-
    factor(heatmap_df_long$hm_8grp, levels = group_order)



heatmap_df_scaled_long <-
    pivot_longer(heatmap_df_scaled,
                 names_to = "hm_8grp",
                 values_to = "scaled_mean_relab",
                 -taxon)

heatmap_df_scaled_long$hm_8grp <-
    factor(heatmap_df_scaled_long$hm_8grp, levels = group_order)


# plot heatmap

fig5_hm_plot <-
    ggplot(heatmap_df_scaled_long, aes(x = hm_8grp, y = taxon)) +
    coord_cartesian(xlim = c(0.5, 8.5), clip = "off") +
    geom_tile(aes(fill = scaled_mean_relab), colour = "white") +
    theme_bw() +
    geom_text(
        x = 2.5,
        y = length(core_otus_hm_grp) + 1,
        label = "unburnt",
        hjust = 0.5,
        size = 5
    ) +
    geom_text(
        x = 6.5,
        y = length(core_otus_hm_grp) + 1,
        label = "burnt",
        hjust = 0.5,
        size = 5
    ) +
    geom_text(data = heatmap_df_long, aes(
        x = hm_8grp,
        y = taxon,
        label = round(mean_relab, 1)
    )) +
    geom_vline(xintercept = 4.5,
               size = 1.25,
               col = "#333333") +
    labs(x = "", y = "") +
    scale_fill_gradient("scaled\nvalue", low = "white", high = "#727274") +
    scale_x_discrete(expand = c(0, 0),
                     labels = label_by_hm_grp) +
    scale_y_discrete(expand = c(0, 0),
                     position = "right",
                     labels = label_by_tax_order) +
    theme(
        axis.text.x = element_text(
            angle = 45,
            vjust = 1,
            hjust = 1
        ),
        text = element_text(size = 12),
        plot.margin = unit(c(2, 0.2, 0, 0), "cm"),
        legend.position = "bottom"
    )

fig5_hm_plot










