
# plotter settings



##### custom ggplot2 themes ----

# theme attribute for subplots in figure 2
fig2_nmds_theme <- function() {
    theme(
        legend.title = element_text(face = "bold"),
        legend.direction = "vertical",
        legend.key.height = unit(0.3, "line"),
        plot.margin = unit(c(2.5, 0, 0, 0.2), "cm"),
        legend.margin = margin(0, 0, 0, 0),
        legend.box.margin = unit(c(0.2, 0, 0.2, 0), "cm")
    )
}

# overall figure legend theme
theme_legend <- function() {
    theme(legend.position = "bottom",
          legend.title = element_text(size = 8, face = "bold"),
          legend.text = element_text(size = 7, margin = margin(0, 0, 0, 0)),
          legend.background = element_blank(),
          legend.margin = margin(0, 0, 0, 0, unit = "mm"),
          legend.key = element_blank(),
          legend.box = "vertical",
          legend.box.background = element_rect(colour = "black", fill = NA),
          legend.spacing.y = unit(0, "mm"),
          legend.box.margin = margin(0, 2, 1, 2, unit = "mm"))
}

# theme attributes for facetted plots
theme_stripped <- function() {
    theme_linedraw() +
        theme_legend() +
        theme(panel.grid.major.x = element_blank(),
              panel.grid.minor = element_blank(),
              panel.grid.major.y = element_line(color = 'grey77'),
              axis.title.x = element_text(size = 8),
              axis.title.y = element_blank(),
              axis.text = element_text(size = 7),
              strip.placement = "outside",
              strip.background.y = element_rect(fill = NA, color = NA),
              strip.background.x = element_rect(fill = 'grey42', color = 'grey42'),
              strip.text.x = element_text(size = 8, face = "bold"),
              strip.text.y = element_text(size = 8, vjust = -1, color = 'black'))
}


##### substrate color schemes (nmds plots), chem re-labeller and tree color schemes ----

color_by_substrate <- c(  ## fig2
`female, body` = "#440154",  # dark purple
`female, gut` = "#C896D3",  # light purple (was #2D708E, petrol)
`male, body` = "#22A884",  # light green a
`male, gut` = "#BBDF27",  # lime green
`pre-colonization` = "#20A387",  # light green b
`1st instar, colonized` = "#C9404A",  # dark pink/red
`1st instar, uncolonized` = "#F6D645",  # yellow
`3rd instar, colonized` = "#390963",  # dark purple
`3rd instar, uncolonized` = "#F67F13",  # orange
`beetle` = "#000004",  # black
`phloem, 1st instar` = "#F67F13",  # orange
`phloem, 3rd instar` = "#84206B",  # purple
`phloem, no larvae` = "#F6D645"  # yellow
)


shape_by_firehist_and_site <- c(1, 2, 16, 17)

chem_facet_labeller <- c(
    `cn_ratio` = "C:N",
    `cp_ratio` = "C:P",
    `np_ratio` = "N:P",
    `KB`  = "Knutby\n(unburnt)",
    `HSB` = "Hälleskogsbrännan\n(burnt)",
    `SK`  = "Skyttorp\n(unburnt)",
    `OJ`  = "Ecopark Öjesjön\n(burnt)",
    `pred_cn` = "predicted C:N",
    `pred_cp` = "predicted C:P",
    `pred_np` = "predicted N:P",
    `unburnt` = "Unburnt sites\n(Knutby, Skyttorp)",
    `burnt`   = "Burnt sites\n(Hälleskogsbrännan, Ecopark Öjesjön)"
)


color_by_tree <- c(
    `H1` = "#170C3AFF",
    `H2` = "#5B116EFF",
    `H3` = "#9B2964FF",
    `K2` = "#440154FF",
    `K3` = "#414487FF",
    `K5` = "#2A788EFF",
    `O1` = "#D74B3FFF",
    `O2` = "#F8880DFF",
    `O4` = "#F6D645FF",
    `S2` = "#22A884FF",
    `S3` = "#7AD151FF",
    `S5` = "#FDE725FF"
)


color_by_tree_3color <- c(
    `H1` = "#D74B3FFF",
    `H2` = "#F8880DFF",
    `H3` = "#F6D645FF",
    `K2` = "#3CBB75FF",
    `K3` = "#3A5E8CFF",
    `K5` = "#9B2964FF",
    `O1` = "#D74B3FFF",
    `O2` = "#F8880DFF",
    `O4` = "#F6D645FF",
    `S2` = "#3CBB75FF",
    `S3` = "#3A5E8CFF",
    `S5` = "#9B2964FF"
)


label_by_site <- c(
"KB" = "KB (unburnt)",
"SK" = "SK (unburnt)",
"HSB" = "HSB (burnt)",
"OJ" = "OJ (burnt)"
)



